==> ICA-1.5.tar.gz: ICA-1.5/src/MSI/Gen2Spec/interface.c <==
/*
   Owner:       Copyright 1992 The Ohio State University,
                Integrated Chameleon Architecture
   Module:      $RCSfile: interface.c,v $
   Purpose:     

   Programmer:  Conleth O'Connell
   Reviewer:    
   Revision:    $Revision: 1.8 $
   Date:        $Date: 92/06/02 11:46:24 $

   HISTORY
   $Log:	interface.c,v $
 * Revision 1.8  92/06/02  11:46:24  boyd
 * Finished merge with Pete's changes to SymbolPlace.
 * 
 * 
 * Revision 1.7  92/05/29  16:20:13  boyd
 * Changes to improve resizing, consisting mostly of replacing Form widgets with
 * Group, Table, and Viewform.
 * 
 * 
 * Revision 1.6  92/05/20  15:49:18  ware
 * 
 * For some reason, certain window manager settings prevent the event
 * handler from ever getting called.  I don't quite understand why.  What
 * I do know is that making it a translation fixes the problem.  That is
 * about all that happens.  I change SymbolPlace from being an event
 * handler to being an action proc.
 * 
 * Revision 1.5  92/03/16  12:19:56  ware
 * Merging cso and OSU versions.  Changes for titles.
 * 
 * Revision 1.3  1992/02/28  23:46:06  cso
 * Added SetFocus action to feedback the keyboard focus in the mapping shell
 *
 * Revision 1.2  1992/02/28  14:48:44  cso
 * Integrated the creation of the mapping interface into CreateInterface
 *
 * Revision 1.1  1992/02/06  05:32:49  cso
 * Initial revision
 *
 * Revision 1.1  1992/01/08  19:54:52  cso
 * Initial revision
 *

   Functions Index:
   AVAIL   NAME DEPENDS ON INTERNALLY      EXTERNALLY
   -----   ----            ----------      ----------

*/

/* #INCLUDES */

#include "widgets.h"
#include "types.h"
#include "defs.h"

/*  EXTERNS  */

#include "mapping.h"
#include "menubar.h"
#include "callbacks.h"
#include "panel.h"
#include "permute.h"
#include "prodlist.h"
#include "status.h"

/*  GLOBALS  */

static String
   Fallbacks[] = {
   /************************/
   /***   Accelerators   ***/
   /************************/
   "*prevprod*accelerators:	<Key>Home:	set() notify() reset()",
   "*nextprod*accelerators:	<Key>End:	set() notify() reset()",
   "*prevalt*accelerators:	<Key>R9:	set() notify() reset()",
   "*nextalt*accelerators:	<Key>R15:	set() notify() reset()",
   "*prevperm*accelerators:	<Key>Up:	set() notify() reset()",
   "*nextperm*accelerators:	<Key>Down:	set() notify() reset()",
   "Gen2Spec.title:		Map General to Specific Structure",
   "Gen2Spec.iconName:		Map General to Specific Structure",
   "*map-spec-form.title:       Map General to Specific Structure: Map to Specific Form Strings",
   "*map-spec-form.iconName:	Map General to Specific Structure: Map to Specific Form Strings",
   /************************/
   /***     Sizing       ***/
   /************************/
   "*pnodeview.prefWidth:   550",
   "*pnodeview.minWidth:    100",
   "*nodeview.prefWidth:    550",
   "*nodeview.minWidth:     100",
   "*prodview.prefWidth:    550",
   "*prodview.minWidth:     100",
   "*prodview.prefHeight:   300",
   "*prodview.minHeight:    50",
   "*ctxtview.prefWidth:    150",
   "*ctxtview.minWidth:     100",
   "*ctxtview.prefHeight:   100",
   "*ctxtview.minHeight:    50",
   "*rexview.prefWidth:     150",
   "*rexview.minWidth:      100",
   "*rexview.prefHeight:    100",
   "*rexview.minHeight:     50",
   "*dtmtagsview.prefWidth:    150",
   "*dtmtagsview.minWidth:     50",
   "*dtmtagsview.prefHeight:   500",
   "*dtmtagsview.minHeight:    50",
   "*dtmtagscol.stretch:       False",
   "*dtmregexpview.prefWidth:  150",
   "*dtmregexpview.minWidth:   50",
   "*dtmregexpview.prefHeight: 500",
   "*dtmregexpview.minHeight:  50",
   "*dtmregexpcol.stretch:     True",
   "*dtminstview.prefWidth:    250",
   "*dtminstview.minWidth:     50",
   "*dtminstview.prefHeight:   500",
   "*dtminstview.minHeight:    50",
   "*dtminstcol.stretch:       True",
   "*Statw.prefHeight:      96",
   "*Statw.minHeight:       20",
   "*Statw.stretch:         False",
   "*statframe.stretch:     False",
   (char *) NULL
   };

static XtActionsRec
   TextActions[] = {
                     {"DoPanel",    DoPanel},
                     {"RemoveDup",  RemoveDup},
                     {"SetFocus",   SetFocus},
                     {"TextReturn", TextReturn},
		     {"SymbolPlace",SymbolPlace},
                     {NULL,         NULL}
		   };

Widget
   Toplevel;



/*
   FUNCTION: 		QuickQuit

   Synopsis: 
       Quits during development on key strokes.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE     WHO      REASON

   Globals used:
       none

   Globals Modified:
       none

   Return value:	void

   Range:		none
*/

static void
QuickQuit(w, client_data, event)

Widget
   w;
caddr_t
   client_data;
XEvent
   *event;

{
   int
      i;
   char
      text[10];
   KeySym
      keys;
   
   /*
    * quit the program if the user hits a 'q'
    */
   i = XLookupString(event, text, 10, &keys, 0);
   if ((i == 1) && ((text[0] == 'Q') || (text[0] == 'q')))
   {
      exit(0);
   }
   return;
}



/*
   FUNCTION: 		CreateInterface

   Synopsis: 
       Open up the display connection and call the appropriate
       creation routines.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE     WHO      REASON

   Globals used:
       none

   Globals Modified:
       none

   Return value:	XtAppContext

   Range:		NULL or an application context
*/

XtAppContext
CreateInterface(argc, argv)

int
   argc;
char
   **argv;

{
   Widget
      frame,
      menubar,
      listframe,
      listlbls, listviews,
      mapping,
      prods;
   XtAppContext
      appcon;
   
   Toplevel = XtVaAppInitialize( 
       &appcon, "Gen2Spec", NULL, 0, &argc, argv, Fallbacks,
       XtNinput,            True,
#ifdef HARDCODEDTITLE
       XtNtitle,            TITLE,
       XtNiconName,         TITLE,
#endif
       XtNallowShellResize, True,
       NULL );

#ifdef SYNC
   XSynchronize(XtDisplay(Toplevel), True);
#endif

   XtAppAddActions(appcon, TextActions, XtNumber(TextActions));

   frame = XtVaCreateManagedWidget( "Frame",
       groupWidgetClass, Toplevel,
       XtNspacing, 8,
       NULL );

   CreateMenubar(frame);

   listframe = XtVaCreateManagedWidget( "listframe",
       tableWidgetClass, frame,
       XtNalignment,   gaFill,
       XtNmargin,      8,
       XtNhorzMargin,  0,
       XtNvertMargin,  0,
       XtNhorzSpacing, 8,
       XtNvertSpacing, 8,
       XtNstretch,     True,
       NULL );
   listlbls = XtVaCreateWidget( "listlbls",
       tableColObjectClass, listframe,
       NULL );
   listviews = XtVaCreateWidget( "listviews",
       tableColObjectClass, listframe,
       XtNstretch, True,
       NULL );

   mapping = CreateMapDisplay( listframe, listlbls, listviews );
   prods   = CreateProdList( listframe, listlbls, listviews );

   CreateStatus(frame);

   XtRealizeWidget(Toplevel);

   SetupFileDialog(Toplevel);

   CreateMappingShell(Toplevel);

#ifdef DEBUG
   XtAddEventHandler(frame, KeyPressMask, False, QuickQuit, NULL);
#endif

   XtInstallAllAccelerators(frame, frame);

   return(appcon);
}

==> ICA-1.6.tar.gz: ICA-1.6/src/MSI/Gen2Spec/interface.c <==
/*
   Owner:       Copyright 1992 The Ohio State University,
                Integrated Chameleon Architecture
   Module:      interface.c,v
   Purpose:     

   Programmer:  Conleth O'Connell
   Reviewer:    
   Revision:    1.9
   Date:        1993/04/19 17:06:54

   HISTORY
   interface.c,v
 * Revision 1.9  1993/04/19  17:06:54  ware
 * Merged John Boyds changes.
 *
 * Revision 1.8  92/06/02  11:46:24  boyd
 * Finished merge with Pete's changes to SymbolPlace.
 * 
 * 
 * Revision 1.7  92/05/29  16:20:13  boyd
 * Changes to improve resizing, consisting mostly of replacing Form widgets with
 * Group, Table, and Viewform.
 * 
 * 
 * Revision 1.6  92/05/20  15:49:18  ware
 * 
 * For some reason, certain window manager settings prevent the event
 * handler from ever getting called.  I don't quite understand why.  What
 * I do know is that making it a translation fixes the problem.  That is
 * about all that happens.  I change SymbolPlace from being an event
 * handler to being an action proc.
 * 
 * Revision 1.5  92/03/16  12:19:56  ware
 * Merging cso and OSU versions.  Changes for titles.
 * 
 * Revision 1.3  1992/02/28  23:46:06  cso
 * Added SetFocus action to feedback the keyboard focus in the mapping shell
 *
 * Revision 1.2  1992/02/28  14:48:44  cso
 * Integrated the creation of the mapping interface into CreateInterface
 *
 * Revision 1.1  1992/02/06  05:32:49  cso
 * Initial revision
 *
 * Revision 1.1  1992/01/08  19:54:52  cso
 * Initial revision
 *

   Functions Index:
   AVAIL   NAME DEPENDS ON INTERNALLY      EXTERNALLY
   -----   ----            ----------      ----------

*/

/* #INCLUDES */

#include "widgets.h"
#include "types.h"
#include "defs.h"

/*  EXTERNS  */

#include "mapping.h"
#include "menubar.h"
#include "callbacks.h"
#include "panel.h"
#include "permute.h"
#include "prodlist.h"
#include "status.h"

/*  GLOBALS  */

static String
   Fallbacks[] = {
   /************************/
   /***   Accelerators   ***/
   /************************/
   "*prevprod*accelerators:	<Key>Home:	set() notify() reset()",
   "*nextprod*accelerators:	<Key>End:	set() notify() reset()",
   "*prevalt*accelerators:	<Key>R9:	set() notify() reset()",
   "*nextalt*accelerators:	<Key>R15:	set() notify() reset()",
   "*prevperm*accelerators:	<Key>Up:	set() notify() reset()",
   "*nextperm*accelerators:	<Key>Down:	set() notify() reset()",
   "Gen2Spec.title:		Map General to Specific Structure",
   "Gen2Spec.iconName:		Map General to Specific Structure",
   "*map-spec-form.title:       Map General to Specific Structure: Map to Specific Form Strings",
   "*map-spec-form.iconName:	Map General to Specific Structure: Map to Specific Form Strings",
   /************************/
   /***     Sizing       ***/
   /************************/
   "*pnodeview.prefWidth:   550",
   "*pnodeview.minWidth:    100",
   "*nodeview.prefWidth:    550",
   "*nodeview.minWidth:     100",
   "*prodview.prefWidth:    550",
   "*prodview.minWidth:     100",
   "*prodview.prefHeight:   300",
   "*prodview.minHeight:    50",
   "*ctxtview.prefWidth:    150",
   "*ctxtview.minWidth:     100",
   "*ctxtview.prefHeight:   100",
   "*ctxtview.minHeight:    50",
   "*rexview.prefWidth:     150",
   "*rexview.minWidth:      100",
   "*rexview.prefHeight:    100",
   "*rexview.minHeight:     50",
   "*dtmtagsview.prefWidth:    150",
   "*dtmtagsview.minWidth:     50",
   "*dtmtagsview.prefHeight:   500",
   "*dtmtagsview.minHeight:    50",
   "*dtmtagscol.stretch:       False",
   "*dtmregexpview.prefWidth:  150",
   "*dtmregexpview.minWidth:   50",
   "*dtmregexpview.prefHeight: 500",
   "*dtmregexpview.minHeight:  50",
   "*dtmregexpcol.stretch:     True",
   "*dtminstview.prefWidth:    250",
   "*dtminstview.minWidth:     50",
   "*dtminstview.prefHeight:   500",
   "*dtminstview.minHeight:    50",
   "*dtminstcol.stretch:       True",
   "*Statw.prefHeight:      96",
   "*Statw.minHeight:       20",
   "*Statw.stretch:         False",
   "*statframe.stretch:     False",
   (char *) NULL
   };

static XtActionsRec
   TextActions[] = {
                     {"DoPanel",    DoPanel},
                     {"RemoveDup",  RemoveDup},
                     {"SetFocus",   SetFocus},
                     {"TextReturn", TextReturn},
		     {"SymbolPlace",SymbolPlace},
                     {NULL,         NULL}
		   };

Widget
   Toplevel;



/*
   FUNCTION: 		QuickQuit

   Synopsis: 
       Quits during development on key strokes.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE     WHO      REASON

   Globals used:
       none

   Globals Modified:
       none

   Return value:	void

   Range:		none
*/

static void
QuickQuit(w, client_data, event)

Widget
   w;
caddr_t
   client_data;
XEvent
   *event;

{
   int
      i;
   char
      text[10];
   KeySym
      keys;
   
   /*
    * quit the program if the user hits a 'q'
    */
   i = XLookupString((XKeyEvent *) event, text, 10, &keys, 0);
   if ((i == 1) && ((text[0] == 'Q') || (text[0] == 'q')))
   {
      exit(0);
   }
   return;
}



/*
   FUNCTION: 		CreateInterface

   Synopsis: 
       Open up the display connection and call the appropriate
       creation routines.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE     WHO      REASON

   Globals used:
       none

   Globals Modified:
       none

   Return value:	XtAppContext

   Range:		NULL or an application context
*/

XtAppContext
CreateInterface(argc, argv)

int
   argc;
char
   **argv;

{
   Widget
      frame,
      menubar,
      listframe,
      listlbls, listviews,
      mapping,
      prods;
   XtAppContext
      appcon;
   
   Toplevel = XtVaAppInitialize( 
       &appcon, "Gen2Spec", NULL, 0, &argc, argv, Fallbacks,
       XtNinput,            True,
#ifdef HARDCODEDTITLE
       XtNtitle,            TITLE,
       XtNiconName,         TITLE,
#endif
       XtNallowShellResize, True,
       NULL );

#ifdef SYNC
   XSynchronize(XtDisplay(Toplevel), True);
#endif

   XtAppAddActions(appcon, TextActions, XtNumber(TextActions));

   frame = XtVaCreateManagedWidget( "Frame",
       groupWidgetClass, Toplevel,
       XtNspacing, 8,
       NULL );

   CreateMenubar(frame);

   listframe = XtVaCreateManagedWidget( "listframe",
       tableWidgetClass, frame,
       XtNalignment,   gaFill,
       XtNmargin,      8,
       XtNhorzMargin,  0,
       XtNvertMargin,  0,
       XtNhorzSpacing, 8,
       XtNvertSpacing, 8,
       XtNstretch,     True,
       NULL );
   listlbls = XtVaCreateWidget( "listlbls",
       tableColObjectClass, listframe,
       NULL );
   listviews = XtVaCreateWidget( "listviews",
       tableColObjectClass, listframe,
       XtNstretch, True,
       NULL );

   mapping = CreateMapDisplay( listframe, listlbls, listviews );
   prods   = CreateProdList( listframe, listlbls, listviews );

   CreateStatus(frame);

   XtRealizeWidget(Toplevel);

   SetupFileDialog(Toplevel);

   CreateMappingShell(Toplevel);

#ifdef DEBUG
   XtAddEventHandler(frame, KeyPressMask, False, QuickQuit, NULL);
#endif

   XtInstallAllAccelerators(frame, frame);

   return(appcon);
}
